dhcpkit.ipv6.server.handlers.preference module
==============================================

.. automodule:: dhcpkit.ipv6.server.handlers.preference
    :members:
    :undoc-members:
    :show-inheritance:
